==> i2b2-eureka-package-1.1-bin.zip: i2b2-send-patient-set-plugin-1.1/PatientSetSender/PatientSetSender_config.js <==
/*-
 * #%L
 * i2b2 Send Patient Set Plugin
 * %%
 * Copyright (C) 2015 - 2016 Emory University
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
i2b2.PatientSetSender.SERVICE_URL = 'https://ubuntu/i2b2-eureka-service';
i2b2.PatientSetSender.EUREKA_SERVICES_URL = 'https://ubuntu/eureka-services';
i2b2.PatientSetSender.RECEIVER_DISPLAY_NAME = 'Receiver';
i2b2.PatientSetSender.RECEIVER_SEND_URL = 'http://localhost';

i2b2.PatientSetSender.context = {
	DEFAULT: function (patientSet) {
		return {
			postBody: JSON.stringify(patientSet)
		};
	},
	CVRG: function (patientSet) {
		var username = patientSet.username;
		var userIdVar = username ? username.substring(username.indexOf('#') + 1) : username;
		var cvrgPatientSet = {
				queryName: i2b2.PatientSetSender.model.prsRecord.sdxInfo.sdxDisplayName.substring(0, 50),
				userId: userIdVar,
				subjects: patientSet.patients
			};
		return {
			json: Object.toJSON(cvrgPatientSet)
		};
	}
};

i2b2.PatientSetSender.contextualize = i2b2.PatientSetSender.context.DEFAULT;

==> i2b2-eureka-package-1.3.1-bin.zip: i2b2-send-patient-set-plugin-1.3.1/PatientSetSender/PatientSetSender_config.js <==
/*-
 * #%L
 * i2b2 Send Patient Set Plugin
 * %%
 * Copyright (C) 2015 - 2016 Emory University
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
i2b2.PatientSetSender.SERVICE_URL = 'https://ubuntu/eurekaclinical-i2b2-integration-webapp';
i2b2.PatientSetSender.EUREKA_SERVICES_URL = 'https://ubuntu/eureka-webapp';
i2b2.PatientSetSender.RECEIVER_DISPLAY_NAME = 'Receiver';
i2b2.PatientSetSender.RECEIVER_SEND_URL = 'http://localhost';

i2b2.PatientSetSender.context = {
	DEFAULT: function (patientSet) {
		return {
			postBody: JSON.stringify(patientSet)
		};
	},
	CVRG: function (patientSet) {
		var username = patientSet.username;
		var userIdVar = username ? username.substring(username.indexOf('#') + 1) : username;
		var cvrgPatientSet = {
				queryName: i2b2.PatientSetSender.model.prsRecord.sdxInfo.sdxDisplayName.substring(0, 50),
				userId: userIdVar,
				subjects: patientSet.patients
			};
		return {
			json: Object.toJSON(cvrgPatientSet)
		};
	}
};

i2b2.PatientSetSender.contextualize = i2b2.PatientSetSender.context.DEFAULT;
